@@ -5,13 +5,20 @@ from enum import Enum
 from typing import Any, Dict, List, Tuple, Union
 
 
+class TaskType(str, Enum):
+    CLASSIFICATION = 'classification'
+    REGRESSION = 'regression'
+
+
 class Dataset:
-    predictedY: List
+    task_type: TaskType
+    predicted_y: List
     features: List[List[int]]
-    featureNames: List[str]
-    probabilityY: List
-    trueY: List
-    classNames: List[str]
+    feature_names: List[str]
+    probability_y: List
+    true_y: List
+    class_names: List[str]
+    categorical_map: Dict[int, List[str]]
 
 
 class BoundedCoordinates:
@@ -46,16 +53,8 @@ class ModelClass(str, Enum):
     BLACKBOX = 'blackbox'
 
 
-class ModelMethod(str, Enum):
-    CLASSIFIER = 'classifier'
-    REGRESSOR = 'regressor'
-
-
 class ModelExplanationData:
     modelClass: ModelClass
-    method: ModelMethod
-    predictedY: List
-    probabilityY: List[List[float]]
     explanationMethod: str
     precomputedExplanations: PrecomputedExplanations
 
@@ -77,7 +76,7 @@ class CausalMetric:
 
 class CausalPolicyGains:
     recommended_policy_gains: float
-    treatment_gains: List[float]
+    treatment_gains: Dict[str, float]
     treatments: List[str]
 
 
@@ -97,6 +96,7 @@ class CausalPolicyTreeInternal:
 
 class CausalPolicy:
     treatment_feature: str
+    control_treatment: str
     local_policies: List[Dict[str, Any]]
     policy_gains: CausalPolicyGains
     policy_tree: Union[CausalPolicyTreeInternal, CausalPolicyTreeLeaf]
